==> nextcloud-22.2.5.tar.bz2: nextcloud/apps/activity/l10n/hr.js <==
OC.L10N.register(
    "activity",
    {
    "Copied!" : "Kopirano!",
    "Not supported!" : "Nije podržano!",
    "Press ⌘-C to copy." : "Pritisnite ⌘-C za kopiranje.",
    "Press Ctrl-C to copy." : "Pritisnite Ctrl-C za kopiranje.",
    "{name} (invisible)" : "{name} (nevidljivo)",
    "{name} (restricted)" : "{name} (ograničeno)",
    "Home" : "Početna",
    "in {path}" : "u {path}",
    "This stream will show events like additions, changes & shares" : "Ova lista će prikazati događaje poput dodavanja, promjena i dijeljenja",
    "There are no events for this filter" : "Nema događaja koji odgovaraju ovom filtru",
    "Today" : "Danas",
    "Yesterday" : "Jučer",
    "Open {filename}" : "Otvori {filename}",
    "Personal activity feed for %s" : "Sažetak osobnih aktivnosti za %s",
    "Your feed URL is invalid" : "Nevažeći URL sažetka",
    "Your settings have been updated." : "Vaše su postavke ažurirane.",
    "Settings have been updated." : "Postavke su ažurirane.",
    "Recent activity" : "Nedavna aktivnost",
    "Daily activity summary for %s" : "Dnevni sažetak aktivnosti za %s",
    "_and %n more _::_and %n more _" : ["i još %n ","i još %n ","i još %n "],
    "All activities" : "Sve aktivnosti",
    "By others" : "Od drugih",
    "By you" : "Vaše",
    "Hello %s" : "Pozdrav %s",
    "Hello %s," : "Pozdrav %s",
    "There was some activity at %s" : "Bilo je aktivnosti na %s",
    "Mail" : "Pošta",
    "Push" : "Push",
    "Activity" : "Aktivnost",
    "Notifications" : "Obavijesti",
    "This application enables users to view a log of activities about them or about files." : "Ova aplikacija omogućuje korisnicima pregled zapisa aktivnosti u vezi s njima ili datotekama.",
    "This application enables users to view actions related to their files in Nextcloud.\n\t\tOnce enabled, users will see a new icon “Activity” in their apps menu.\n\t\tWhen clicked, a new page appears for users to track the activity related to files – from new files, to deleted files, move, rename, updates and shared activity.\n\t\tThe user can configure their individual activity settings in their personal menu.\n\t\tThis sets the type of activity to record, as well as whether to the user sees their own activities,\n\t\twhether these are only available online, and whether they get an email digest on a regular basis.\n\t\tMore information is available in the Activity documentation." : "Ova aplikacija korisnicima omogućuje pregledavanje radnji u vezi s njihovim datotekama u Nextcloudu.\n\t\tKada je omogućena, korisnici će u izborniku aplikacija vidjeti novu ikonu „Aktivnost”.\n\t\tKlikom na ikonu prikazat će se nova stranica na kojoj korisnici mogu pratiti aktivnosti u vezi s datotekama – od novih datoteka, izbrisanih datoteka, premještanja, preimenovanja, ažuriranja i dijeljenih aktivnosti.\n\t\tKorisnik može konfigurirati pojedinačne postavke aktivnosti u osobnom izborniku.\n\t\tTime se određuje vrsta aktivnosti koju treba bilježiti, vidi li korisnik vlastite aktivnosti,\n\t\tjesu li aktivnosti dostupne samo na mreži i prima li korisnik redovito pregled aktivnosti putem e-pošte.\n\t\tViše informacija dostupno je u dokumentaciji Aktivnosti.",
    "No activity yet" : "Trenutno nema aktivnosti",
    "Unable to load the activity list" : "Nije moguće učitati popis aktivnosti",
    "No activities" : "Nema aktivnosti",
    "Activity feed" : "Sažetak aktivnosti",
    "Enable notification emails" : "Omogući e-poštu s obavijestima",
    "Default settings" : "Zadane postavke",
    "Configure the default notification settings for new users." : "Konfigurirajte osnovne postavke obavijesti za nove korisnike.",
    "You need to set up your email address before you can receive notification emails." : "Morate navesti svoju adresu e-pošte kako biste primali poruke s obavijestima.",
    "As soon as possible" : "Čim prije moguće",
    "Hourly" : "Svaki sat",
    "Daily" : "Svakodnevno",
    "Weekly" : "Svaki tjedan",
    "Choose for which activities you want to get an email or push notification." : "Odaberite za koje aktivnosti želite primati obavijest e-poštom ili push obavijesti.",
    "Choose for which activities you want to get a push notification." : "Odaberite za koje aktivnosti želite primati push obavijesti.",
    "Send daily activity summary in the morning" : "Šalji dnevni sažetak aktivnosti ujutro",
    "Settings" : "Postavke",
    "Enable RSS feed" : "Omogući sažetak događaja RSS",
    "RSS feed" : "Sažetak događaja RSS",
    "Personal Activity Settings" : "Postavke osobnih aktivnosti",
    "No more events to load" : "Nema više događaja za učitavanje",
    "An error occurred while loading activities" : "Pogreška pri učitavanju aktivnosti",
    "Load more activities" : "Učitaj više aktivnosti",
    "Activity notification for %s" : "Obavijest o aktivnosti za %s",
    "This application enables users to view actions related to their files in Nextcloud." : "Ova aplikacija korisnicima omogućuje pregledavanje radnji u vezi s njihovim datotekama u Nextcloudu.",
    "Send notification emails:" : "Šalji e-poštu s obavijestima:",
    "activities" : "aktivnosti"
},
"nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;");

==> nextcloud-28.0.6.tar.bz2: nextcloud/apps/activity/l10n/hr.js <==
OC.L10N.register(
    "activity",
    {
    "Personal activity feed for %s" : "Sažetak osobnih aktivnosti za %s",
    "Your feed URL is invalid" : "Nevažeći URL sažetka",
    "Activity feed" : "Sažetak aktivnosti",
    "Your settings have been updated." : "Vaše su postavke ažurirane.",
    "Settings have been updated." : "Postavke su ažurirane.",
    "Recent activity" : "Nedavna aktivnost",
    "No activities" : "Nema aktivnosti",
    "More activities" : "Više aktivnosti",
    "Daily activity summary for %s" : "Dnevni sažetak aktivnosti za %s",
    "_and %n more _::_and %n more _" : ["i još %n ","i još %n ","i još %n "],
    "All activities" : "Sve aktivnosti",
    "By others" : "Od drugih",
    "By you" : "Vaše",
    "Activity at %s" : "Aktivnost na %s",
    "Hello %s" : "Pozdrav %s",
    "Hello %s," : "Pozdrav %s",
    "There was some activity at %s" : "Bilo je aktivnosti na %s",
    "Mail" : "Pošta",
    "Push" : "Push",
    "Activity" : "Aktivnost",
    "Notifications" : "Obavijesti",
    "This application enables people to view a log of activities about them, their files or other data." : "Ova aplikacija omogućuje korisnicima pregled aktivnosti o njima, njihovim datotekama ili ostalim podacima.",
    "Activity notification configuration" : "Konfiguracija obavijesti o aktivnostima",
    "Send email" : "Pošalji poruku e-pošte",
    "Send push notification" : "Pošalji \"push\" notifikaciju",
    "Today" : "Danas",
    "Yesterday" : "Jučer",
    "You need to set up your email address before you can receive notification emails." : "Morate navesti svoju adresu e-pošte kako biste primali poruke s obavijestima.",
    "Send activity emails" : "Šalji e-poštu s pregledom aktivnosti",
    "As soon as possible" : "Čim prije moguće",
    "Hourly" : "Svaki sat",
    "Daily" : "Svakodnevno",
    "Weekly" : "Svaki tjedan",
    "You commented" : "Vi ste komentirali",
    "Message deleted by author" : "Autor je izbrisao poruku",
    "Open {filename}" : "Otvori {filename}",
    "in {path}" : "u {path}",
    "Home" : "Početna",
    "This stream will show events like additions, changes & shares" : "Ova lista će prikazati događaje poput dodavanja, promjena i dijeljenja",
    "No activity yet" : "Trenutno nema aktivnosti",
    "Activity settings" : "Postavke Aktivnosti",
    "Enable RSS feed" : "Omogući sažetak događaja RSS",
    "RSS feed" : "Sažetak događaja RSS",
    "Copy RSS feed link" : "Kopiraj poveznicu sažetka događaja.",
    "Personal notification settings" : "Osobne postavke obavijesti",
    "Unable to load the activity list" : "Nije moguće učitati popis aktivnosti",
    "Notification" : "Obavijest",
    "Enable notification emails" : "Omogući e-poštu s obavijestima",
    "Choose for which activities you want to get an email or push notification." : "Odaberite za koje aktivnosti želite primati obavijest e-poštom ili push obavijesti.",
    "Choose for which activities you want to get a push notification." : "Odaberite za koje aktivnosti želite primati push obavijesti.",
    "Daily activity summary" : "Dnevni sažetak aktivnosti",
    "Send daily activity summary in the morning" : "Šalji dnevni sažetak aktivnosti ujutro",
    "Default settings" : "Zadane postavke",
    "Configure the default notification settings for new accounts." : "Konfiguriraj zadane postavke obavijesti za nove račune.",
    "Unable to save the settings" : "Nije moguće spremiti postavke",
    "No more events to load" : "Nema više događaja za učitavanje",
    "Copied!" : "Kopirano!",
    "Not supported!" : "Nije podržano!",
    "Press ⌘-C to copy." : "Pritisnite ⌘-C za kopiranje.",
    "Press Ctrl-C to copy." : "Pritisnite Ctrl-C za kopiranje.",
    "{name} (invisible)" : "{name} (nevidljivo)",
    "{name} (restricted)" : "{name} (ograničeno)",
    "There are no events for this filter" : "Nema događaja koji odgovaraju ovom filtru"
},
"nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;");
